@@ -3,6 +3,6 @@
 
 __author__ = """David Munechika"""
 __email__ = 'david.munechika@gatech.edu'
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 
-import visual_auditor.visual_auditor
\ No newline at end of file
+from visual_auditor.visual_auditor import *
\ No newline at end of file
